#
# spec file for package yast2-rmt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-rmt
Version:        1.3.5
Release:        1.3

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.bz2
Source99:       %{name}-rpmlintrc

Requires:       rmt-server >= 2.5.0
Requires:       yast2
Requires:       yast2-ruby-bindings

BuildRequires:  update-desktop-files
BuildRequires:  yast2
BuildRequires:  yast2-devtools
BuildRequires:  yast2-ruby-bindings
#for install task
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake)
# for tests
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)

Summary:        YaST2 - Module to configure RMT
License:        GPL-2.0-only
Group:          System/YaST
URL:            https://github.com/yast/yast-rmt
# ExcludeArch synced with our main dependency: rmt-server
ExcludeArch:    %{ix86} s390

%description
Provides the YaST module to configure the Repository Mirroring Tool (RMT) Server.

%prep
%setup -n %{name}-%{version}

%check
rake test:unit

%install
rake install DESTDIR="%{buildroot}"

%files
%defattr(-,root,root)
%{yast_dir}/clients/*.rb
%{yast_dir}/lib/rmt
%{yast_dir}/lib/rmt.rb
%{yast_desktopdir}/rmt.desktop
%{yast_dir}/data/rmt

%doc COPYING
%doc README.md

%build

%changelog
* Thu Feb  8 2024 Luis Caparroz <luis.caparroz@suse.com>
- Adds UI dialog to allow the user to retry the SCC credential validation when
  the request times out (bsc#1218084).
- Adds HTTP User-Agent to requests to the SCC API and changes the enpoint for
  credential validation.
- Version 1.3.5
* Thu Jun  9 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Sync ExcludeArch with rmt-server: whenever rmt-server is not
  available, the yast2-rmt module can't be usable neither.
- No longer build as noarch: as the package is not installable on
  all architectures, it is by definition not 'architecture
  independent'.
- Add rpmlintrc, filtering out "E: no-binary": the package is
  intentionally not marked noarch.
- 1.3.4
* Wed Apr  7 2021 Josef Reidinger <jreidinger@suse.com>
- Adapted unit test to recent changes in Yast::Report (related to
  bsc#1179893).
- 1.3.3
* Mon Jun  8 2020 Jesús Bermúdez Velázquez <jesus.bv@suse.com>
- Version 1.3.2
- Handle Common Name length (bsc#1172674)
* Wed May 13 2020 Ladislav Slezák <lslezak@suse.cz>
- Changed placeholders in translatable strings (%%<> -> %%{})
  to better support gettext language format tags (bsc#1171555)
- 1.3.1
* Wed Jan 15 2020 Ivan Kapelyukhin <ikapelyukhin@suse.com>
- Version 1.3.0
- Add support for forwarding registration data from RMT to SCC
* Thu Aug 22 2019 schubi@suse.de
- Using rb_default_ruby_abi tag in the spec file in order to
  handle several ruby versions (bsc#1146403).
- 1.2.3
* Tue Feb 12 2019 skotov@suse.com
- Release version 1.2.2
- Pass SSL password to Cheetah CLI interface securely (CVE-2018-20105: bsc#1119835)
* Fri Feb  1 2019 fschueller@suse.com
- Release version 1.2.1
- Launch as root from gnome-shell menu (bsc#1123562)
* Mon Jan 14 2019 thutterer@suse.com
- Remove broken hyperlink from help (bsc#1120672)
* Fri Jan  4 2019 hschmidt@suse.com
- Release version 1.2.0
* Thu Dec 20 2018 vzepedamas@suse.com
- Allow user to skip registration (bsc#1119386)
* Thu Dec  6 2018 skotov@suse.com
- version 1.1.2
- [CVE-2018-17957] Secure MySQL credentials (bsc#1117602)
* Mon Oct 29 2018 thutterer@suse.com
- version 1.1.1
- Translation fixes
- Follow YaST text style guide
- Remove broken back-buttons
* Mon Oct 29 2018 thutterer@suse.com
- version 1.1.0
- Add setup step to open firewall ports for HTTP and HTTPS (fate#326634)
* Wed Oct  3 2018 igonzalezsosa@suse.com
- version 1.0.4
- Adapt to the new YaST2 systemd API (bsc#1107253)
* Tue Aug 14 2018 fschnizlein@suse.com
- version 1.0.3
- Change configuration file path to new location (rmt-server >= 1.0.6)
- Hide database password in summary (bsc#1102053)
- Fix visual issues with text alignment
* Thu Jul  5 2018 wstephenson@suse.com
- version 1.0.2
- Translation fixes
* Mon Jun 25 2018 skotov@suse.com
- version 1.0.1
- setting and validating CA private key password (bsc#1099324)
- reload nginx after configuration
* Fri May 18 2018 fschueller@suse.com
- version 1.0.0
- Release for SLES15 (bsc#1093879)
- UI cleanups
- Enable timers with rmt service start
- Add final configuration summary
* Wed Apr 18 2018 ikapelyukhin@suse.com
- version 0.0.4
- Allow a preexisting SSL CA:
  https://github.com/SUSE/yast2-rmt/pull/11
* Tue Apr  3 2018 ikapelyukhin@suse.com
- version 0.0.3
- Add setup steps for SSL certificate generation (fate#325115)
* Mon Mar  5 2018 ikapelyukhin@suse.com
- version 0.0.2
- Add setup steps for SCC and DB (fate#325115)
* Tue Jan 30 2018 thutterer@suse.com
- create new YaST module for RMT configuration
- only a WIP message is displayed so far
